@@ -1,9 +1,9 @@
 Facter.add(:ip6tables_version) do
-  confine :kernel => :linux
+  confine kernel: :Linux
   setcode do
     version = Facter::Util::Resolution.exec('ip6tables --version')
     if version
-      version.match(/\d+\.\d+\.\d+/).to_s
+      version.match(%r{\d+\.\d+\.\d+}).to_s
     else
       nil
     end
