@@ -1,11 +1,14 @@
+#
+# firewall.rb
+#
 class Puppet::Provider::Firewall < Puppet::Provider
-
   # Prefetch our rule list. This is ran once every time before any other
   # action (besides initialization of each object).
   def self.prefetch(resources)
-    debug("[prefetch(resources)]")
+    debug('[prefetch(resources)]')
     instances.each do |prov|
-      if resource = resources[prov.name] || resources[prov.name.downcase]
+      resource = resources[prov.name] || resources[prov.name.downcase]
+      if resource
         resource.provider = prov
       end
     end
@@ -15,7 +18,7 @@ class Puppet::Provider::Firewall < Puppet::Provider
   # existing status with properties[:foo].
   def properties
     if @property_hash.empty?
-      @property_hash = query || {:ensure => :absent}
+      @property_hash = query || { ensure: :absent }
       @property_hash[:ensure] = :absent if @property_hash.empty?
     end
     @property_hash.dup
@@ -25,7 +28,7 @@ class Puppet::Provider::Firewall < Puppet::Provider
   # getting some double entendre here....
   def query
     self.class.instances.each do |instance|
-      if instance.name == self.name or instance.name.downcase == self.name
+      if instance.name == name || instance.name.downcase == name
         return instance.properties
       end
     end
