@@ -1,13 +1,13 @@
 require 'spec_helper_acceptance'
 
-describe "firewall class" do
-  it 'should run successfully' do
+describe 'firewall class' do
+  it 'runs successfully' do
     pp = "class { 'firewall': }"
 
     # Run it twice and test for idempotency
-    apply_manifest(pp, :catch_failures => true)
+    apply_manifest(pp, catch_failures: true)
     if do_catch_changes
-      expect(apply_manifest(pp, :catch_failures => true).exit_code).to be_zero
+      expect(apply_manifest(pp, catch_failures: true).exit_code).to be_zero
     end
   end
 
@@ -15,9 +15,9 @@ describe "firewall class" do
     pp = "class { 'firewall': ensure => stopped }"
 
     # Run it twice and test for idempotency
-    apply_manifest(pp, :catch_failures => true)
+    apply_manifest(pp, catch_failures: true)
     if do_catch_changes
-      expect(apply_manifest(pp, :catch_failures => true).exit_code).to be_zero
+      expect(apply_manifest(pp, catch_failures: true).exit_code).to be_zero
     end
   end
 
@@ -25,9 +25,9 @@ describe "firewall class" do
     pp = "class { 'firewall': ensure => running }"
 
     # Run it twice and test for idempotency
-    apply_manifest(pp, :catch_failures => true)
+    apply_manifest(pp, catch_failures: true)
     if do_catch_changes
-      expect(apply_manifest(pp, :catch_failures => true).exit_code).to be_zero
+      expect(apply_manifest(pp, catch_failures: true).exit_code).to be_zero
     end
   end
 end
