@@ -7,9 +7,8 @@ describe 'firewall DSCP' do
   end
 
   describe 'dscp ipv4 tests' do
-    context 'set_dscp 0x01' do
-      it 'applies' do
-        pp = <<-EOS
+    context 'when set_dscp 0x01' do
+      pp1 = <<-PUPPETCODE
           class { '::firewall': }
           firewall {
             '1000 - set_dscp':
@@ -20,21 +19,20 @@ describe 'firewall DSCP' do
               chain     => 'OUTPUT',
               table     => 'mangle',
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      PUPPETCODE
+      it 'applies' do
+        apply_manifest(pp1, catch_failures: true)
       end
 
-      it 'should contain the rule' do
+      it 'contains the rule' do
         shell('iptables-save -t mangle') do |r|
-          expect(r.stdout).to match(/-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1000 - set_dscp" -j DSCP --set-dscp 0x01/)
+          expect(r.stdout).to match(%r{-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1000 - set_dscp" -j DSCP --set-dscp 0x01})
         end
       end
     end
 
-    context 'set_dscp_class EF' do
-      it 'applies' do
-        pp = <<-EOS
+    context 'when set_dscp_class EF' do
+      pp2 = <<-PUPPETCODE
           class { '::firewall': }
           firewall {
             '1001 EF - set_dscp_class':
@@ -45,24 +43,23 @@ describe 'firewall DSCP' do
               chain          => 'OUTPUT',
               table          => 'mangle',
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      PUPPETCODE
+      it 'applies' do
+        apply_manifest(pp2, catch_failures: true)
       end
 
-      it 'should contain the rule' do
+      it 'contains the rule' do
         shell('iptables-save') do |r|
-          expect(r.stdout).to match(/-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1001 EF - set_dscp_class" -j DSCP --set-dscp 0x2e/)
+          expect(r.stdout).to match(%r{-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1001 EF - set_dscp_class" -j DSCP --set-dscp 0x2e})
         end
       end
     end
   end
 
-  if default['platform'] !~ /el-5/ and default['platform'] !~ /sles-10/
+  if default['platform'] !~ %r{el-5} && default['platform'] !~ %r{sles-10}
     describe 'dscp ipv6 tests' do
-      context 'set_dscp 0x01' do
-        it 'applies' do
-          pp = <<-EOS
+      context 'when set_dscp 0x01' do
+        pp3 = <<-PUPPETCODE
             class { '::firewall': }
             firewall {
               '1002 - set_dscp':
@@ -74,21 +71,20 @@ describe 'firewall DSCP' do
                 table     => 'mangle',
                 provider  => 'ip6tables',
             }
-          EOS
-
-          apply_manifest(pp, :catch_failures => true)
+        PUPPETCODE
+        it 'applies' do
+          apply_manifest(pp3, catch_failures: true)
         end
 
-        it 'should contain the rule' do
+        it 'contains the rule' do
           shell('ip6tables-save -t mangle') do |r|
-            expect(r.stdout).to match(/-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1002 - set_dscp" -j DSCP --set-dscp 0x01/)
+            expect(r.stdout).to match(%r{-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1002 - set_dscp" -j DSCP --set-dscp 0x01})
           end
         end
       end
 
-      context 'set_dscp_class EF' do
-        it 'applies' do
-          pp = <<-EOS
+      context 'when set_dscp_class EF' do
+        pp4 = <<-PUPPETCODE
             class { '::firewall': }
             firewall {
               '1003 EF - set_dscp_class':
@@ -100,18 +96,17 @@ describe 'firewall DSCP' do
                 table          => 'mangle',
                 provider       => 'ip6tables',
             }
-          EOS
-
-          apply_manifest(pp, :catch_failures => true)
+        PUPPETCODE
+        it 'applies' do
+          apply_manifest(pp4, catch_failures: true)
         end
 
-        it 'should contain the rule' do
+        it 'contains the rule' do
           shell('ip6tables-save') do |r|
-            expect(r.stdout).to match(/-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1003 EF - set_dscp_class" -j DSCP --set-dscp 0x2e/)
+            expect(r.stdout).to match(%r{-A OUTPUT -p tcp -m multiport --ports 997 -m comment --comment "1003 EF - set_dscp_class" -j DSCP --set-dscp 0x2e})
           end
         end
       end
     end
   end
-
 end
