@@ -6,10 +6,7 @@ describe 'param based tests' do
     ip6tables_flush_all_tables
   end
 
-  it 'test various params', :unless => (default['platform'].match(/el-5/) || fact('operatingsystem') == 'SLES') do
-    iptables_flush_all_tables
-
-    ppm = <<-EOS
+  ppm1 = <<-PUPPETCODE
     firewall { '100 test':
       table     => 'raw',
       socket    => 'true',
@@ -17,30 +14,33 @@ describe 'param based tests' do
       jump      => 'LOG',
       log_level => 'debug',
     }
-    EOS
-
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to eq(2)
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to be_zero
-  end
-
-  it 'test log rule' do
+  PUPPETCODE
+  values = [2, 0]
+  it 'test various params', unless: (default['platform'].match(%r{el-5}) || fact('operatingsystem') == 'SLES') do
     iptables_flush_all_tables
 
-    ppm = <<-EOS
+    values.each do |value|
+      expect(apply_manifest(ppm1, catch_failures: true).exit_code).to eq(value)
+    end
+  end
+
+  ppm2 = <<-PUPPETCODE
     firewall { '998 log all':
       proto     => 'all',
       jump      => 'LOG',
       log_level => 'debug',
     }
-    EOS
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to eq(2)
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to be_zero
-  end
-
-  it 'test log rule - changing names' do
+  PUPPETCODE
+  values = [2, 0]
+  it 'test log rule' do
     iptables_flush_all_tables
 
-    ppm1 = <<-EOS
+    values.each do |value|
+      expect(apply_manifest(ppm2, catch_failures: true).exit_code).to eq(value)
+    end
+  end
+
+  ppm3 = <<-PUPPETCODE
     firewall { '004 log all INVALID packets':
       chain      => 'INPUT',
       proto      => 'all',
@@ -49,9 +49,8 @@ describe 'param based tests' do
       log_level  => '3',
       log_prefix => 'IPTABLES dropped invalid: ',
     }
-    EOS
-
-    ppm2 = <<-EOS
+  PUPPETCODE
+  ppm4 = <<-PUPPETCODE
     firewall { '003 log all INVALID packets':
       chain      => 'INPUT',
       proto      => 'all',
@@ -60,49 +59,44 @@ describe 'param based tests' do
       log_level  => '3',
       log_prefix => 'IPTABLES dropped invalid: ',
     }
-    EOS
-
-    expect(apply_manifest(ppm1, :catch_failures => true).exit_code).to eq(2)
-
-    ppm = <<-EOS + "\n" + ppm2
+  PUPPETCODE
+  ppm5 = <<-PUPPETCODE + "\n" + ppm4
       resources { 'firewall':
         purge => true,
       }
-    EOS
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to eq(2)
-  end
-
-  it 'test chain - changing names' do
+  PUPPETCODE
+  it 'test log rule - changing names' do
     iptables_flush_all_tables
 
-    ppm1 = <<-EOS
+    expect(apply_manifest(ppm3, catch_failures: true).exit_code).to eq(2)
+    expect(apply_manifest(ppm5, catch_failures: true).exit_code).to eq(2)
+  end
+
+  ppm6 = <<-PUPPETCODE
     firewall { '004 with a chain':
       chain => 'INPUT',
       proto => 'all',
     }
-    EOS
-
-    ppm2 = <<-EOS
+  PUPPETCODE
+  ppm7 = <<-PUPPETCODE
     firewall { '004 with a chain':
       chain => 'OUTPUT',
       proto => 'all',
     }
-    EOS
-
-    apply_manifest(ppm1, :expect_changes => true)
-
-    ppm = <<-EOS + "\n" + ppm2
+  PUPPETCODE
+  _ppm8 = <<-PUPPETCODE + "\n" + ppm7
       resources { 'firewall':
         purge => true,
       }
-    EOS
-    expect(apply_manifest(ppm2, :expect_failures => true).stderr).to match(/is not supported/)
-  end
-
-  it 'test log rule - idempotent' do
+  PUPPETCODE
+  it 'test chain - changing names' do
     iptables_flush_all_tables
 
-    ppm1 = <<-EOS
+    apply_manifest(ppm6, expect_changes: true)
+    expect(apply_manifest(ppm7, expect_failures: true).stderr).to match(%r{is not supported})
+  end
+
+  ppm9 = <<-PUPPETCODE
     firewall { '004 log all INVALID packets':
       chain      => 'INPUT',
       proto      => 'all',
@@ -111,42 +105,47 @@ describe 'param based tests' do
       log_level  => '3',
       log_prefix => 'IPTABLES dropped invalid: ',
     }
-    EOS
-
-    expect(apply_manifest(ppm1, :catch_failures => true).exit_code).to eq(2)
-    expect(apply_manifest(ppm1, :catch_failures => true).exit_code).to be_zero
-  end
-
-  it 'test src_range rule' do
+  PUPPETCODE
+  values = [2, 0]
+  it 'test log rule - idempotent' do
     iptables_flush_all_tables
 
-    ppm = <<-EOS
+    values.each do |value|
+      expect(apply_manifest(ppm9, catch_failures: true).exit_code).to eq(value)
+    end
+  end
+
+  ppm10 = <<-PUPPETCODE
     firewall { '997 block src ip range':
       chain     => 'INPUT',
       proto     => 'all',
       action    => 'drop',
       src_range => '10.0.0.1-10.0.0.10',
     }
-    EOS
-
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to eq(2)
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to be_zero
-  end
-
-  it 'test dst_range rule' do
+  PUPPETCODE
+  values = [2, 0]
+  it 'test src_range rule' do
     iptables_flush_all_tables
 
-    ppm = <<-EOS
+    values.each do |value|
+      expect(apply_manifest(ppm10, catch_failures: true).exit_code).to eq(value)
+    end
+  end
+
+  ppm11 = <<-PUPPETCODE
     firewall { '998 block dst ip range':
       chain     => 'INPUT',
       proto     => 'all',
       action    => 'drop',
       dst_range => '10.0.0.2-10.0.0.20',
     }
-    EOS
+  PUPPETCODE
+  values = [2, 0]
+  it 'test dst_range rule' do
+    iptables_flush_all_tables
 
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to eq(2)
-    expect(apply_manifest(ppm, :catch_failures => true).exit_code).to be_zero
+    values.each do |value|
+      expect(apply_manifest(ppm11, catch_failures: true).exit_code).to eq(value)
+    end
   end
-
 end
